.. Perun documentation master file, created by
   sphinx-quickstart on Mon Oct 16 20:46:06 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Perun's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   profile
   cli
   collectors
   postprocessors
   views
   jobs
   degradation
   fuzzing
   config
   logs
   internals

.. toctree::
    :maxdepth: 2
    :caption: Changes:

    changelog
